<?php $TRANSLATIONS = array(
"Music" => "Hudba",
"songs" => "skladby",
"albums" => "alba",
"Add to playlist" => "Přidat do seznamu skladeb",
"Add album to playlist" => "Přidat album do seznamu skladeb",
"Play" => "Přehrát",
"Pause" => "Pozastavit",
"Previous" => "Předchozí",
"Next" => "Následující",
"Mute" => "Ztlumit",
"Unmute" => "Obnovit",
"Rescan Collection" => "Znovu prohledat",
"Artist" => "Umělec",
"Album" => "Album",
"Title" => "Název",
"Media" => "Média",
"Ampache address:" => "Adresa ampache:"
);
